@@ -18,9 +18,9 @@
    Copyright (C) 1998-1999 Kling & Hautzinger GmbH
    Copyright (C) 1999 Norihiko Sawa <sawa@yb3.so-net.ne.jp>
    Copyright (C) 2000 Karl Heinz Kremer <khk@khk.net>
-   Copyright (C) 2001-2004 SEIKO EPSON Corporation
+   Copyright (C) 2001-2005 SEIKO EPSON Corporation
 
-   This file is part of the SANE package.
+   This file is part of the EPKOWA SANE backend.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -61,9 +61,16 @@
 #ifndef epkowa_h
 #define epkowa_h
 
-#include <sys/ioctl.h>
-
-#include <sys/types.h>
+/* Make a consistently named debugging interface available to all
+   modules used by this backend.  This assumes that these modules
+   include us.  Note that sanei_debug.h assumes that BACKEND_NAME
+   is defined.  */
+#ifndef BACKEND_NAME
+#define BACKEND_NAME epkowa
+#endif
+#define DEBUG_DECLARE_ONLY
+#include "sane/sanei_debug.h"
+#include "sane/sanei_backend.h"	/* for Option_Value, sigh */
 
 /* some string constants that are used in the config file */
 
@@ -161,6 +168,9 @@ typedef enum
   SANE_EPSON_USB		/* USB interface */
 } Epson_Connection_Type;
 
+
+/*! Software abstraction of the \e physical device.
+ */
 struct Epson_Device
 {
   struct Epson_Device *next;
@@ -217,20 +227,25 @@ struct Epson_Device
   SANE_Int devtype;
   SANE_Int doctype;
 
+  int fd;
+
   unsigned int productID;
 
   EpsonCmd cmd;
   EpsonScanHard scan_hard;
+
+  struct interpreter_type *interpreter;
 };
 
 typedef struct Epson_Device Epson_Device;
 
 
-
+/*! Software representation of the \e logical device.
+ */
 struct Epson_Scanner
 {
   struct Epson_Scanner *next;
-  int fd;
+
   Epson_Device *hw;
   SANE_Option_Descriptor opt[NUM_OPTIONS];
   Option_Value val[NUM_OPTIONS];
@@ -253,9 +268,6 @@ struct Epson_Scanner
   SANE_Int lines_written;	/* debug variable */
   SANE_Bool option_has_changed;	/* did one of the options change it's value? */
 
-  int timer_count;
-  double *table;
-  SANE_Byte *s1_buf;
   SANE_Bool adf_has_been_fed;
 };
 
