@@ -1,5 +1,4 @@
 #include <sys/types.h>
-#include <sane/sanei_usb.h>
 #include "epkowa_usb.h"
 
 
@@ -14,21 +13,17 @@ SANE_Word sanei_epson_usb_product_ids[] = {
   0x10b,			/* GT-7700 / Perfection 1240 */
   0x10c,			/* GT-6700 / Perfection 640 */
   0x10e,			/* ES-2200 / Expression 1680 */
-  0x10f,			/* GT-7200 / Perfection 1250 */
   0x110,			/* GT-8200 / Perfection 1650 */
   0x112,			/* GT-9700 / Perfection 2450 */
-  0x116,			/* GT-9400 / Perfection 3170 */
-  0x118,			/* GT-F600 / Perfection 4180 */
   0x11b,			/* GT-9300 / Perfection 2400 */
   0x11c,			/* GT-9800 / Perfection 3200 */
-  0x11d,			/* GT-7300 / Perfection 1260 */
   0x11e,			/* GT-8300 / Perfection 1660 */
-  0x121,			/* GT-F500 / Perfection 2480 */
-				/* GT-F550 / Perfection 2580 */
   0x126,			/* ES-7000 / GT-15000 */
   0x128,			/* GT-X700 / Perfection 4870 */
   0x129,			/* ES-10000G / Expression 10000XL */
   0x12a,			/* GT-X800 / Perfection 4990 */
+  0x12b,			/* ES-H300 / GT-2500 */    
+  0x12c,			/* GT-X900 / Perfection V700/V750 */
   0x801,			/* CC-600  / Stylus CX5100/CX5200/CX5300/CX5400 */
   0x802,			/* CC-570  / Stylus CX3100/CX3200 */
   0x805,			/*         / Stylus CX6300/CX6400/CX6500/CX6600 */
@@ -39,9 +34,24 @@ SANE_Word sanei_epson_usb_product_ids[] = {
   0x80f,			/*         / Stylus Photo RX420/RX430 */
   0x810,			/* PM-A900 / Stylus Photo RX700 */
   0x811,			/* PM-A870 / Stylus Photo RX620/RX630 */
+  0x813,			/*         / Stylus CX6600 (sane-devel) */
   0x814,			/* PM-A700 */
   0x815,			/* LP-A500 / AcuLaser CX11 */
   0x817,			/* LP-M5500 */
+  0x818,			/*         / Stylus CX3700/CX3800/DX3800 */
+  0x819,			/* PX-A650 / Stylus CX4700/CX4800/DX4800 */
+  0x81a,			/* PM-A750 / Stylus Photo RX520/RX530 */
+  0x81c,			/* PM-A890 / Stylus Photo RX640/RX640 */
+  0x81d,			/* PM-A950 */
+  0x81f,			/*         / Stylus CX7700/CX7800 */
+  0x820,			/*         / Stylus CX4100/CX4200/DX4200 */
+  0x827,			/* PM-A820 */
+  0x828,			/* PM-A970 */
+  0x82A,			/* PM-A920 */
+  0x82B,			/*         / Stylus CX4900/CX5000/DX5000 */
+  0x82E,			/* PX-A720 / Stylus CX5900/CX6000/DX6000 */
+  0x82F,			/*         / Stylus CX3900/DX4000 */
+  0x830,			/*         / Stylus CX2800/CX2900/ME200 */
   0				/* last entry - this is used for devices that are specified
 				   in the config file as "usb <vendor> <product>" */
 };
